@@ -1,14 +1,18 @@
 getPCA.test <-
-function(data, bs_basis, PCAcoef, gp, emodel = c("classical", "robust")){
+function(object, data){
   
-  emodel <- match.arg(emodel)
+  bs_basis <- object$bs_basis
+  PCAcoef <- object$PCAcoef
+  gp <- object$gp
+  emodel <- object$emodel
+  mean.tr <- c(object$meanScore$coefs)
   n <- dim(data)[1]
   p <- dim(data)[2]
   dimnames(data) = list(as.character(1:n), as.character(1:p))
   pcaobj <- smooth.basisPar(gp, t(data), bs_basis, Lfdobj=NULL, lambda=0)$fd
   
   if(emodel == "classical"){
-    sdata <- scale(t(pcaobj$coefs), scale = FALSE)
+    sdata <- scale(t(pcaobj$coefs), center = mean.tr, scale = FALSE)
     pcaobj2 <- pcaobj
     pcaobj2$coefs <- t(sdata)
     PCAscore_test = inprod(pcaobj2, PCAcoef)
@@ -16,8 +20,7 @@ function(data, bs_basis, PCAcoef, gp, emodel = c("classical", "robust")){
     for(i in 1:dim(PCAcoef$coefs)[2])
       colnames(PCAscore_test)[i] = paste("Score", i, sep = "")
   }else if(emodel == "robust"){
-    mean_coef <- pcaPP::l1median(t(pcaobj$coefs), trace = -1)
-    sdata <- scale(t(pcaobj$coefs), center = mean_coef, scale = FALSE) 
+    sdata <- scale(t(pcaobj$coefs), center = mean.tr, scale = FALSE) 
     pcaobj2 <- pcaobj
     pcaobj2$coefs <- t(sdata)
     PCAscore_test = inprod(pcaobj2, PCAcoef)
